Transforms
-----------------


AttenuationTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.attenuation

.. autoclass:: AttenuationTransform
    :members:
    :inherited-members:


DeskewTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.deskew

.. autoclass:: DeskewTransform
    :members:
    :inherited-members:


FixedPatternTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.fixedpattern

.. autoclass:: FixedPatternTransform
    :members:
    :inherited-members:


HighpassTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.highpass

.. autoclass:: HighpassTransform
    :members:
    :inherited-members:


HistogramEqualisationTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.histogram

.. autoclass:: HistogramEqualisationTransform
    :members:
    :inherited-members:


MotionStabilisationTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.motion

.. autoclass:: MotionStabilisationTransform
    :members:
    :inherited-members:


PaddingTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.padding

.. autoclass:: PaddingTransform
    :members:
    :inherited-members:


PeriodicNoiseSuppressionTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.periodic

.. autoclass:: PeriodicNoiseSuppressionTransform
    :members:
    :inherited-members:


RangeTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.range

.. autoclass:: RangeTransform
    :members:
    :inherited-members:


SaltAndPepperTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.salt_pepper

.. autoclass:: SaltPepperTransform
    :members:
    :inherited-members:


VarianceStabilisationTransform
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.transforms.variance_stabilisation

.. autoclass:: VarianceStabilisationTransform
    :members:
    :inherited-members:

